@@ -18,7 +18,7 @@ import os
 #maads = imp.load_source('maads','sendfiles.py')
 
     
-def dotraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,dependentvariable,url,theserverlocalname='',summer='6,7,8',winter='12,1,2,3',shoulder='4,5,9,10,11',trainingpercentage=75,retrainingdays=0,retraindeploy=0,shuffle=0,username='',passw='',company='',email=''):
+def dotraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,dependentvariable,url,throttle=-1,theserverlocalname='',summer='6,7,8',winter='12,1,2,3',shoulder='4,5,9,10,11',trainingpercentage=75,retrainingdays=0,retraindeploy=0,shuffle=0,username='',passw='',company='',email=''):
 #   rmsg=maads.uploadcsvfortraining(thefile,username,passw,autofeature,removeoutliers,hasseasonality,dependentvariable,company,email,url,summer,winter,shoulder,trainingpercentage)
    #print(rmsg)
    if autofeature != -1 and autofeature != 1 and autofeature != 0:
@@ -59,7 +59,7 @@ def dotraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,depe
    else:
       retraindeploy=int(retraindeploy)
       
-   rmsg=maads.uploadcsvfortraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,dependentvariable,url,summer,winter,shoulder,trainingpercentage,retrainingdays,retraindeploy,shuffle,theserverlocalname,username,passw,company,email)
+   rmsg=maads.uploadcsvfortraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,dependentvariable,url,throttle,summer,winter,shoulder,trainingpercentage,retrainingdays,retraindeploy,shuffle,theserverlocalname,username,passw,company,email)
    rms=rmsg.split(":")[0]
    rms=rms.lstrip('\n')
    rms=rms.rstrip('\n')
